%define srcname    %{name}-c
%define major_c    19
%define libname    %mklibname %{name} %{major_c}
%define pluginname %mklibname %{name}-plugins
%define develname  %mklibname %{name} -d

Summary:	Libraries to use the Unidata network Common Data Form (netCDF)
Name:		netcdf
Version:	4.9.2
Release:	%mkrel 4
Group:		Development/C
License:	BSD
URL:		https://www.unidata.ucar.edu/software/netcdf/
Source0:	https://github.com/Unidata/netcdf-c/archive/v%{version}/%{srcname}-%{version}.tar.gz
# Fix plugins - https://github.com/Unidata/netcdf-c/pull/2431
#Patch0:         netcdf-plugin.patch
Patch1:         netcdf-4.9.2-soname.patch
#https://github.com/Unidata/netcdf-c/issues/2849
Patch2:         netcdf-4.9.2-types.patch

Requires(post): info-install
Requires(postun): info-install
BuildRequires:	hdf5-devel
BuildRequires:	pkgconfig(blosc)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libzip)
BuildRequires:	pkgconfig(zlib)
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:	valgrind
BuildRequires:	texinfo
BuildRequires:	tetex-latex
BuildRequires:	groff

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C,
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the
creation, access, and sharing of scientific data. The netCDF software was
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is:

   o Self-Describing. A netCDF file includes information about the data it
     contains.

   o Network-transparent. A netCDF file is represented in a form that can be
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers.

   o Direct-access. A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding data.

   o Appendable. Data can be appended to a netCDF dataset along one dimension
     without copying the dataset or redefining its structure. The structure of
     a netCDF dataset can be changed, though this sometimes causes the dataset
     to be copied.

   o Shareable. One writer and multiple readers may simultaneously access the
     same netCDF file.

%package -n	%{libname}
Summary:	C libraries for netcdf-4
Group:		System/Libraries
Provides:	lib%{name} = %{version}-%{release}
Requires:	%{pluginname} = %{version}-%{release}
Requires:	hdf5 = %{_hdf5_version}

%description -n	%{libname}
This package contains the netCDF-4 C libraries.

%package -n     %{pluginname}
Summary:        netcdf-4 HDF5 plugins
Group:          System/Libraries
Provides:       lib%{name}-plugins = %{version}

%description -n %{pluginname}
This package contains the netCDF-4 HDF5 plugins.

%package -n	%{develname}
Summary:	Development files for netcdf-4
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 4.0
Conflicts:	%{name} < 4.1
Conflicts:	%{mklibname %{name} 7}

%description -n %{develname}
This package contains the netCDF-4 header files, shared devel libs, and
man pages.

%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
autoreconf -fi
%configure --enable-shared --disable-static \
		--enable-dap \
		--with-plugin-dir=%{_libdir}/hdf5/plugin \
		--disable-dap-remote-tests


#parallel make was buggy
#{__make} #{_make_output_sync}

%make_build

%install
%make_install

%check
#(eatdirt) one test fails on i586, let's skip it (TOFIX)
#(4.9.2), that test fails on x86_64 now. Let's disable the tests from now.
#ifnarch %%{ix86}
#make check || ( cat */test-suite.log && exit 1 )
#endif

%files
%doc COPYRIGHT README.md RELEASE_NOTES.md
%{_bindir}/ncgen
%{_bindir}/ncgen3
%{_bindir}/ncdump
%{_bindir}/nccopy
%{_bindir}/nc4print
%{_bindir}/ocprint
%{_mandir}/man1/*.1*


%files -n %{libname}
%{_libdir}/libnetcdf.so.%{major_c}{,.*}

%files -n %{pluginname}
%{_libdir}/hdf5/plugin/lib__nc*.so

%files -n %{develname}
%{_bindir}/nc-config
%{_includedir}/*.h
%{_libdir}/*.so
%{_mandir}/man3/*.3*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libnetcdf.settings


%changelog
* Sun May 04 2025 daviddavid <daviddavid> 4.9.2-4.mga10
+ Revision: 2180716
- rebuild for new hdf5 1.14.6

* Sat Dec 07 2024 daviddavid <daviddavid> 4.9.2-3.mga10
+ Revision: 2122457
- rebuild for new hdf5 1.14.5

* Mon Sep 02 2024 eatdirt <eatdirt> 4.9.2-2.mga10
+ Revision: 2092622
- Fix imcompatible pointer types on ix86
- Update to version 4.9.2

* Tue Dec 06 2022 wally <wally> 4.9.0-3.mga9
+ Revision: 1918586
- build with blosc, bzip2 and libzip support

* Tue Dec 06 2022 wally <wally> 4.9.0-2.mga9
+ Revision: 1918569
- split out hdf5 plugins
- install plugins into hdf5 default plugin dir

* Mon Dec 05 2022 eatdirt <eatdirt> 4.9.0-1.mga9
+ Revision: 1918015
- Disable test on ix86
- Upgrade to version 4.9.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Dec 11 2021 eatdirt <eatdirt> 4.8.1-1.mga9
+ Revision: 1761430
- Time to upgrade to version 4.8.1 (tests failure for 4.7.4 against hdf-1.10.8)
+ ns80 <ns80>
- add patches from openSUSE for many CVEs (mga#29241)

* Sun Oct 25 2020 pterjan <pterjan> 4.7.4-3.mga8
+ Revision: 1639337
- Fix a bug in hdf5 code which was made visible by hdf5 1.10.7 on arm but is there everywhere
- Update to 4.7.4
- Switch to upstream patch for unaligned reads
+ akien <akien>
- Update upstream patch to fix arm unaligned access
- Add explicit versioning for hdf5 dep, as a rebuild is necessary on each version change

* Thu Oct 01 2020 pterjan <pterjan> 4.7.3-3.mga8
+ Revision: 1631460
- Fix some unaligned reads breaking on arm

* Tue Sep 29 2020 tv <tv> 4.7.3-2.mga8
+ Revision: 1631217
- we've valgrind on arm
+ pterjan <pterjan>
- Fix displaying of failed tests logs

* Sun Mar 08 2020 pterjan <pterjan> 4.7.3-1.mga8
+ Revision: 1554944
- Update to 4.7.3

* Sat Feb 15 2020 umeabot <umeabot> 4.6.1-6.mga8
+ Revision: 1526052
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Apr 23 2019 daviddavid <daviddavid> 4.6.1-5.mga7
+ Revision: 1394992
- rebuild for new hdf5 1.10.5

* Thu Nov 08 2018 daviddavid <daviddavid> 4.6.1-4.mga7
+ Revision: 1328904
- rebuild for new hdf5 1.10.4

* Sun Sep 23 2018 umeabot <umeabot> 4.6.1-3.mga7
+ Revision: 1299702
- Mageia 7 Mass Rebuild

* Thu Aug 02 2018 tv <tv> 4.6.1-2.mga7
+ Revision: 1246851
- fix upgrade

* Wed Aug 01 2018 eatdirt <eatdirt> 4.6.1-1.mga7
+ Revision: 1246619
- Upgrade to version 4.6.1

* Fri Apr 27 2018 wally <wally> 4.3.3.1-3.mga7
+ Revision: 1222942
- rebuild for new hdf5

* Tue Feb 16 2016 umeabot <umeabot> 4.3.3.1-2.mga6
+ Revision: 961729
- Mageia 6 Mass Rebuild

* Thu Aug 13 2015 fwang <fwang> 4.3.3.1-1.mga6
+ Revision: 864207
- 4.3.3.1

* Tue Jul 21 2015 daviddavid <daviddavid> 4.3.3-2.mga6
+ Revision: 855864
- rebuild with new hdf5

* Wed Jul 01 2015 joequant <joequant> 4.3.3-1.mga6
+ Revision: 849304
- upgrade to 4.3.3

* Wed Oct 15 2014 umeabot <umeabot> 4.3.2-3.mga5
+ Revision: 739814
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.3.2-2.mga5
+ Revision: 682845
- Mageia 5 Mass Rebuild

* Sun Jul 06 2014 pterjan <pterjan> 4.3.2-1.mga5
+ Revision: 645974
- 4.3.2

* Sat Oct 19 2013 umeabot <umeabot> 4.3.0-3.mga4
+ Revision: 530082
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 fwang <fwang> 4.3.0-2.mga4
+ Revision: 455003
- rebuild for new hdf5

* Wed Jun 26 2013 fwang <fwang> 4.3.0-1.mga4
+ Revision: 446779
- new version 4.3.0

* Mon Mar 11 2013 rtp <rtp> 4.2.1.1-4.mga3
+ Revision: 402083
- disable valgrind on arm/mips
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 12 2012 fwang <fwang> 4.2.1.1-2.mga3
+ Revision: 305116
- rebuild for new hdf5

* Wed Sep 19 2012 fwang <fwang> 4.2.1.1-1.mga3
+ Revision: 296140
- cleanup spec
- upload patch
- rediff pkgconfig patch
- new version 4.2.1.1

* Fri Apr 06 2012 fwang <fwang> 4.1.3-3.mga2
+ Revision: 228846
- rebuild for new gcc (bug#5228)
- fix provides
- update file list
- new verison 4.1.3
+ dmorgan <dmorgan>
- Rebuild against new hdf5

* Thu Feb 17 2011 ahmad <ahmad> 4.1.1-3.mga1
+ Revision: 53318
- drop old/unneeded scriptlets
- imported package netcdf


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.1.1-2mdv2011.0
+ Revision: 606819
- rebuild

* Sun Apr 25 2010 Emmanuel Andry <eandry@mandriva.org> 4.1.1-1mdv2010.1
+ Revision: 538712
- New version 4.1.1
- fix obsoletes

* Wed Feb 17 2010 Emmanuel Andry <eandry@mandriva.org> 4.1-1mdv2010.1
+ Revision: 506886
- BR tetex-latex
- netcdf doesn't like parallel on bs
- enable ncgen4 and dap
- disable dap remote tests

  + Funda Wang <fwang@mandriva.org>
    - fix build
    - New version 4.1

* Mon Jan 18 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-11mdv2010.1
+ Revision: 493073
- try to workaround linking issues against hdf5 disabling ld_no_undefined

* Sun Jan 17 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-10mdv2010.1
+ Revision: 492772
- rebuild for hdf5

* Sat Jan 16 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-9mdv2010.1
+ Revision: 492328
- update p0

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-8mdv2010.1
+ Revision: 491906
- add needed requires for devel package

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-7mdv2010.1
+ Revision: 491886
- do not obsolete provided library

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-6mdv2010.1
+ Revision: 491864
- enable netcdf 4
- add linking patch from gentoo
- split libraries by languages
- fix obsoletes/provides

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-5mdv2010.0
+ Revision: 418729
- disable netcdf 4 for now

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-4mdv2010.0
+ Revision: 418635
- add missing provides

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-3mdv2010.0
+ Revision: 418622
- enable ncgen4
  explicit hdf5-devel for devel package

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-2mdv2010.0
+ Revision: 418610
- obsoletes old devel package to ease upgrade

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-1mdv2010.0
+ Revision: 418519
- use libraries policy
- new majors 5 and 6
- disable test (1 test fails)
- New version 4.0.1
- drop P0
- update P1
- build with netcdf4 support (requires HDF5)
- update descriptions

* Fri Apr 10 2009 Funda Wang <fwang@mandriva.org> 4.0-1mdv2009.1
+ Revision: 365885
- fix str fmt

* Thu Aug 14 2008 Emmanuel Andry <eandry@mandriva.org> 4.0-1mdv2009.0
+ Revision: 271832
- New version
- fix license

* Sun Jul 06 2008 Oden Eriksson <oeriksson@mandriva.com> 3.6.3-1mdv2009.0
+ Revision: 232195
- 3.6.3
- added a patch from gentoo, though it won't help much
- use _disable_ld_as_needed and _disable_ld_no_undefined to make it build

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Thauvin <nanardon@mandriva.org>
    - unzip source in %%install instead %%check

* Sun Jan 20 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-4mdv2008.1
+ Revision: 155303
- fix devel static package name
- drop obsoletes

* Sat Jan 19 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-3mdv2008.1
+ Revision: 155130
- fix obsoletes

* Sat Jan 19 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-2mdv2008.1
+ Revision: 155081
- rebuild

* Thu Jan 03 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-1mdv2008.1
+ Revision: 144107
- import netcdf


